<?php
require_once('modules/eps/vendor/autoload.php');

use at\externet\eps_bank_transfer;

class EpsRedirectModuleFrontController extends ModuleFrontController
{
    public function postProcess() 
    {
        $cart = Context::getContext()->cart;
        $customer = new Customer($cart->id_customer);

        $total = (float)$cart->getOrderTotal(true, Cart::BOTH);
        // Connection credentials
        $userID = Configuration::get('EPS_USER_ID');
        $pin    = Configuration::get('EPS_PIN');
        $bic    = Configuration::get('EPS_BIC');
        $iban   = Configuration::get('EPS_IBAN');
        $fullName = Configuration::get('PS_SHOP_NAME');
        $orderTotal = $cart->getOrderTotal()*100;

 
        if(Configuration::get('EPS_TEST_ENABLED') == 1)
        {
            $targetUrl = 'https://routing.eps.or.at/appl/epsSO-test/transinit/eps/v2_5';
        }
        else 
        {
            $targetUrl = 'https://routing.eps.or.at/appl/epsSO/transinit/eps/v2_5';
        }

        $responseUrl = _PS_BASE_URL_.__PS_BASE_URI__.'modules/eps/confirm.php?total='.$total;
        
        /* Link success controller */
        $successUrl  = htmlspecialchars(Context::getContext()->link->getModuleLink('eps', 'success', array()));
        
        /* Link fail controller */
        $failUrl     = htmlspecialchars(Context::getContext()->link->getModuleLink('eps', 'fail', array()));
        
        $transferMsgDetails = new eps_bank_transfer\TransferMsgDetails(
            $responseUrl,
            $successUrl,
            $failUrl
        );
    
        $transferInitiatorDetails = new eps_bank_transfer\TransferInitiatorDetails(
            $userID,
            $pin,
            $bic,
            $fullName,
            $iban,
            $cart->id,
            intval($orderTotal),
            $transferMsgDetails
        );
        
        $transferInitiatorDetails->RemittanceIdentifier = $cart->id;
        $transferInitiatorDetails->SetExpirationMinutes(60);

        foreach ($cart->getProducts() as $product) {
            $article = new eps_bank_transfer\WebshopArticle(
                $product['name'],
                $product['cart_quantity'],
                intval($product['price']*100)
            );
            $transferInitiatorDetails->WebshopArticles[] = $article;
        }    

        // Send TransferInitiatorDetails to Scheme Operator
        $soCommunicator = new eps_bank_transfer\SoCommunicator();
        $plain = $soCommunicator->SendTransferInitiatorDetails($transferInitiatorDetails, $targetUrl);
     
        $xml = new \SimpleXMLElement($plain);
        $soAnswer = $xml->children(eps_bank_transfer\XMLNS_epsp);

        $errorDetails = $soAnswer->BankResponseDetails->ErrorDetails;
        
        if (('' . $errorDetails->ErrorCode) != '000')
        {
            $errorCode = '' . $errorDetails->ErrorCode;
            $errorMsg = '' . $errorDetails->ErrorMsg;
            $this->context->smarty->assign(array(
                'error_code'    => $errorCode,
                'error_message' => $errorMsg,
                'nbProducts'    => $cart->nbProducts()
            ));

            $this->setTemplate('error.tpl');
        }

        else
        {
            $redirectUrl = $soAnswer->BankResponseDetails->ClientRedirectUrl->__toString();
            Tools::redirect($redirectUrl);
        }
    }
}