<?php

/**
 * EPS Payment system for Prestashop 1.6
 *
 * @author Leftor d.o.o.
 * @date 29.08.2018.
 * @version 2.0.2.
 * 
 **/

include(dirname(__FILE__) . '/eps_install.php');
define('_EPS_TRANSLATIONS_XML', 'translations.xml');

if (!defined('_PS_VERSION_')) {
  exit;
}

class Eps extends PaymentModule
{
  const TEMPLATE_DIR = '/views/templates/';

    function __construct() {

    $this->name = 'eps';
    $this->tab = 'payments_gateways';
    $this->version = '2.0.2';
    $this->author = "Stuzza GmbH mit Leftor d.o.o.";
    $this->currencies = false;
    $this->is_configurable = true;
    $this->controllers = array('redirect','success','fail');

    parent::__construct(); /* The parent construct is required for translations */

    if (!is_callable('curl_exec'))
      $this->warning = $this->l('cURL extension must be enabled on your server to use this module.');

    $this->page = basename(__FILE__, '.php');
    $this->displayName = $this->l('eps-Überweisung');
    $this->description = $this->l('eps-Überweisung ist ein sicheres Online-Bezahlsystem. Es wurde in Kooperation mit den österreichischen Banken entwickelt, um Online-Einkäufe über das sichere Online-Banking abwickeln zu können. ');
    $this->bootstrap = true;
  }


/**
   * Installing module from addons
   */
function install() {
  parent::install();
//create tables for transaction logs
  $ppInstall = new EpsInstall();
  $ppInstall->createTables();

  $this->registerHook('payment');
  $this->registerHook('paymentReturn');
}

  /**
   * Uninstalls Eps module
   * Removes all configurations
   */
  function uninstall() {
    $ppInstall = new EpsInstall();

    $ppInstall->uninstall();
    return parent::uninstall();
  }

    /**
   *
   * This will enable configuratio button and will render a form that is in display form function
   * It stores all its options under ps_configuration table
   * @package back-configuration
   */
    public function getContent()
    {
      $this->_preProcess();
      $this->getTranslations();

      $this->context->smarty->assign($this->getFormValues());
      $successUrl = $this->getSuccessUrl();
      $this->context->smarty->assign(array("success_url" => $successUrl));

      return $this->display(__FILE__, self::TEMPLATE_DIR . 'configuration.tpl');

    }

    public function getFormValues() 
    {
      $ppInstall = new EpsInstall();
      $out = array();
      foreach ($ppInstall->getConfigurationNames() as $key) 
      {
        $out[$key] = Configuration::get($key);
      }
      return $out;
    }

    /* For show checkout */
    function hookPayment($params) 
    {
       $this->getTranslations();
       //add css for buttons
       //$this->addModuleAssets();
       return $this->display(__FILE__, self::TEMPLATE_DIR . 'payment_direct.tpl');
    }

 

    /**
   * This updates configuration values after form is submited
   * @package back-configuration
   */
    private function _preProcess() {
      if (Tools::isSubmit('submitEps')) {

        EpsInstall::updateConfiguration();
        $this->context->smarty->assign('updatedconfig', 1);
      } elseIf (Tools::isSubmit('submitTrouble')) {
        EpsInstall::sendTroubleToDevs();
        $this->context->smarty->assign('troublesent', 1);
      }
    }

  /**
   * Returns full return_url form form
   * @return string
   */
  public function getSuccessUrl() {
    return Tools::getProtocol(Tools::usingSecureMode()) . $_SERVER['HTTP_HOST'] . $this->getPathUri() . 'success.php';
  }


/**
   * This reads translations xml file and fills smarty
   * @package back-configuration
   */
public function getTranslations() {
  $this->iso_code = Tools::strtoupper($this->context->language->iso_code);

  $file = dirname(__FILE__) . '/' . _EPS_TRANSLATIONS_XML;
  if (file_exists($file)) {
    $xml = simplexml_load_file($file);
    if (isset($xml) && $xml) {
      $index = -1;
      $content = $default = array();

      while (isset($xml->country[++$index])) {
        $country = $xml->country[$index];
        $country_iso = $country->attributes()->iso_code;

        if (($this->iso_code != 'default') && ($country_iso == $this->iso_code))
          $content = (array) $country;
        elseif ($country_iso == 'default')
          $default = (array) $country;
      }

      $content += $default;
      $this->context->smarty->assign('Eps_content', $content);

      return true;
    }
  }
  return false;
}

}