<?php

/**
 * Eps Presta Demo shop integration
 * 
 * Installation scripts
 * 
 * @author Leftor d.o.o.
 * @version 2.0.0.
 */
if (!defined('_PS_VERSION_'))
    exit;

class EpsInstall 
{
    /**
     * Create Eps tables used for logging failed/success transactions
     * In most cases this will be filled with request sent to server and servers response
     */
    public function createTables() {
	/* Set database */
	$sql = '
		CREATE TABLE IF NOT EXISTS `' . _DB_PREFIX_ . 'eps_log` (
						`id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
						`approved` TINYINT UNSIGNED NOT NULL DEFAULT "0" COMMENT "0-rejected;1-approved;",
						`method` VARCHAR(20) NULL DEFAULT NULL COMMENT "form or direct",
						`post_vars` VARCHAR(20) NULL DEFAULT NULL COMMENT "all post vars posted to eps",
						`url` VARCHAR(150) NULL DEFAULT NULL COMMENT "url where post_vars are posted",
						`complete_cart_info` MEDIUMTEXT NULL COMMENT "saves whole cart info from presta",
						`complete_response` MEDIUMTEXT NULL COMMENT "saves complete response got from eps server",
						`date_created` DATETIME NULL DEFAULT NULL COMMENT "date when this log is made",
						PRIMARY KEY (`id`)
		) ENGINE=' . _MYSQL_ENGINE_ . ' DEFAULT CHARSET=utf8';

	if (!Db::getInstance()->Execute($sql)) {
	    return false;
	} else {
	    return true;
	}
    }

    /**
     * Configuration names used for admin side
     * Those values are stored in 'configuration' table
     * @return array
     */
    public function getConfigurationNames()
    {
		return array(
		    'EPS_USER_ID',
		    'EPS_PIN',
		    'EPS_BIC',
		    'EPS_IBAN',
		    'EPS_TEST_ENABLED'
		);
    }

    /**
     * Update configuratioin
     * When admin saves form under module configuration, this script saves all values to db
     */
    public static function updateConfiguration() {
	$ppInstall = new EpsInstall();
	foreach ($ppInstall->getConfigurationNames() as $key) {
	    Configuration::updateValue($key, Tools::getValue($key));
	}
    }

    /**
     * Delete configuration values
     * Needed for uninstall, remove all configuration values from db
     */
    public function deleteConfiguration() {
	$ppInstall = new EpsInstall();
	foreach ($ppInstall->getConfigurationNames() as $key) {
	    Configuration::deleteByName($key);
	}
    }

    /**
     * Called by Eps->uninstall when user clicks "Uninstall module" from module list
     */
    public function uninstall() {
	//drop logs
	Db::getInstance()->execute('DROP TABLE IF EXISTS `' . _DB_PREFIX_ . 'eps_log`');
	$this->deleteConfiguration();
    }

    /**
     * This will email whole log table to devs
     * Hopefully wont be used at all
     */
    public function sendTroubleToDevs() {
	$html = '';
	$logs = Db::getInstance()->executeS('SELECT * FROM `' . _DB_PREFIX_ . 'eps_log`');
	if ($logs) {
	    $html.='<table><thead><tr><td>ID</td><td>approved</td><td>method</td><td>post vars</td><td>url</td><td>complete cart info</td><td>complete response</td><td>date</td></tr></thead><tbody>';
	    foreach ($logs as $log) {
		$html.='<tr><td>' . $log['id'] . '</td><td>' . $log['approved'] . '</td><td>' . $log['method'] . '</td><td>' . $log['post_vars'] . '</td><td>' . $log['url'] . '</td><td>' . $log['complete_cart_info'] . '</td><td>' . $log['complete_response'] . '</td><td>' . $log['date_created'] . '</td></tr>';
	    }
	    $html.='</tbody></table>';
	}

	$to = 'info@localhost';
	$subject = 'Eps Module Trouble Log v2.0 ['.$_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI'].']';
	$headers = "From: log@localhost.com \r\n";
	$headers .= "MIME-Version: 1.0\r\n";
	$headers .= "Content-Type: text/html; charset=ISO-8859-1\r\n";
	if (mail($to, $subject, $html, $headers)) {
	    return true;
	}
	return false;
    }

}
